@@ -1,14 +1,19 @@
 """Define an object to retrieve air quality info."""
 from __future__ import annotations
 
-from typing import Any, Awaitable, Callable
+from collections.abc import Awaitable, Callable
+from typing import Any, cast
 
 
 class AirQuality:
     """Define an object to manage air quality API calls."""
 
     def __init__(self, request: Callable[..., Awaitable]) -> None:
-        """Iniitialize."""
+        """Initialize.
+
+        Args:
+            request: The request method from the CloudAPI object.
+        """
         self._request = request
 
     async def _nearest(
@@ -17,28 +22,54 @@ class AirQuality:
         latitude: float | str | None = None,
         longitude: float | str | None = None,
     ) -> dict[str, Any]:
-        """Return data from nearest city/station (IP or coordinates)."""
+        """Return data from nearest city/station (IP or coordinates).
+
+        Args:
+            kind: "city" or "station".
+            latitude: A latitude.
+            longitude: A longitude.
+
+        Returns:
+            An API response payload.
+        """
         if latitude and longitude:
             params = {"lat": str(latitude), "lon": str(longitude)}
         else:
             params = {}
 
         data = await self._request("get", f"nearest_{kind}", params=params)
-        return data["data"]
+        return cast(dict[str, Any], data["data"])
 
     async def city(self, city: str, state: str, country: str) -> dict[str, Any]:
-        """Return data for the specified city."""
+        """Return data for the specified city.
+
+        Args:
+            city: A city.
+            state: A state.
+            country: A country.
+
+        Returns:
+            An API response payload.
+        """
         data = await self._request(
             "get", "city", params={"city": city, "state": state, "country": country}
         )
-        return data["data"]
+        return cast(dict[str, Any], data["data"])
 
     async def nearest_city(
         self,
         latitude: float | str | None = None,
         longitude: float | str | None = None,
     ) -> dict[str, Any]:
-        """Return data from nearest city (IP or coordinates)."""
+        """Return data from nearest city (IP or coordinates).
+
+        Args:
+            latitude: A latitude.
+            longitude: A longitude.
+
+        Returns:
+            An API response payload.
+        """
         return await self._nearest("city", latitude, longitude)
 
     async def nearest_station(
@@ -46,18 +77,40 @@ class AirQuality:
         latitude: float | str | None = None,
         longitude: float | str | None = None,
     ) -> dict[str, Any]:
-        """Return data from nearest station (IP or coordinates)."""
+        """Return data from nearest station (IP or coordinates).
+
+        Args:
+            latitude: A latitude.
+            longitude: A longitude.
+
+        Returns:
+            An API response payload.
+        """
         return await self._nearest("station", latitude, longitude)
 
-    async def ranking(self) -> dict[str, Any]:
-        """Return a sorted array of selected major cities in the world."""
+    async def ranking(self) -> list[dict[str, Any]]:
+        """Return a sorted array of selected major cities in the world.
+
+        Returns:
+            An API response payload.
+        """
         data = await self._request("get", "city_ranking")
-        return data["data"]
+        return cast(list[dict[str, Any]], data["data"])
 
     async def station(
         self, station: str, city: str, state: str, country: str
     ) -> dict[str, Any]:
-        """Return data for the specified station."""
+        """Return data for the specified station.
+
+        Args:
+            station: A station name.
+            city: A city.
+            state: A state.
+            country: A country.
+
+        Returns:
+            An API response payload.
+        """
         data = await self._request(
             "get",
             "station",
@@ -68,4 +121,4 @@ class AirQuality:
                 "country": country,
             },
         )
-        return data["data"]
+        return cast(dict[str, Any], data["data"])
